@@ -15,7 +15,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from arjuna.tpi.enums import TimeUnit
+from arjuna.tpi.constant import TimeUnit
 
 class Time:
 
