@@ -132,22 +132,23 @@ class TestSessionController:
         from arjuna import Arjuna
         Arjuna.register_config(config)
 
-    def load_options_from_file(self, fpath):
-        return self.configurator.load_options_from_file(fpath)
+    def load_options_from_file(self, fpath, *, conf_stage):
+        return self.configurator.load_options_from_file(fpath, conf_stage=conf_stage)
 
-    def register_config(self, name, arjuna_options, user_options, parent_config=None):
-        config = self.configurator.register_new_config(arjuna_options, user_options, parent_config)
+    def register_config(self, name, arjuna_options, user_options, *, conf_stage, parent_config=None):
+        config = self.configurator.register_new_config(arjuna_options, user_options, parent_config=parent_config, conf_stage=conf_stage)
         conf = self.__create_config(config, name=name)
         self.__add_to_map(conf)
         return conf
 
     def create_file_data_source(self, record_type, file_name, *arg_pairs):
-        response = self._send_request(
-            ArjunaComponent.DATA_SOURCE,
-            DataSourceActionType.CREATE_FILE_DATA_SOURCE,
-            *arg_pairs
-        )
-        return response.get_data_source_id()
+        raise NotImplementedError()
+        # response = self._send_request(
+        #     ArjunaComponent.DATA_SOURCE,
+        #     DataSourceActionType.CREATE_FILE_DATA_SOURCE,
+        #     *arg_pairs
+        # )
+        # return response.get_data_source_id()
 
     def define_gui(self, automator, label=None, name=None, qual_name=None, def_file_path=None):
         return self.gui_manager.define_gui(automator, label=label, name=name, qual_name=qual_name, def_file_path=def_file_path)
