@@ -20,27 +20,9 @@ import abc
 
 from arjuna.core.reader.excel import *
 from arjuna.tpi.data.record import *
-from arjuna.tpi.helper.arjtype import CIStringDict
 from arjuna.tpi.parser.yaml import Yaml
 
-class IndexedDataReference(metaclass=abc.ABCMeta):
-
-    def __init__(self, pydict):
-        self.__records = pydict
-
-    def record_for(self, index):
-        try:
-            return self.__records[index]
-        except KeyError:
-            raise Exception("Index {} not found in data reference: {}.".format(index, self.__class__.__name__))
-
-    def __str__(self):
-        return str({k: str(v) for k,v in self.self.__records.items()})
-
-    def enumerate(self):
-        for k,v in self.__records.items():
-            print(k, "::", type(v), str(v))
-
+from arjuna.tpi.data.reference import IndexedDataReference, ContextualDataReference
 
 class ExcelIndexedDataReference(IndexedDataReference):
 
@@ -77,57 +59,6 @@ def get_file_name(path):
     name = os.path.basename(path)
     return os.path.splitext(name)[0]
 
-class ContextualDataReference(metaclass=abc.ABCMeta):
-
-    def __init__(self, path):
-        self.__path = path
-        self.__name = get_file_name(path)
-        self.__map = {}
-        self._populate()
-
-    @property
-    def map(self):
-        return self.__map
-
-    @property
-    def path(self):
-        return self.__path
-
-    @property
-    def name(self):
-        return self.__name
-
-    def update(self, data_reference):
-        for context, record in data_reference.map.items():
-            if context not in self.map:
-                self.__map[context] = CIStringDict()
-            self.__map[context].update(record.named_values)
-
-    def update_from_dict(self, context, map):
-        if context not in self.map:
-            self.__map[context] = dict()
-        self.__map[context].update(map)
-
-    def add_record(self, context, record):
-        self.__map[context.lower()] = DataRecord(context="Ref-{}[{}]".format(self.name, context), **record)
-
-    def record_for(self, context):
-        try:
-            return self.__map[context.lower()]
-        except:
-            raise Exception("{} at {} does not contain {} context key.".format(self.__class__.__name__, self.path, context))
-
-    def __str__(self):
-        return str({k: str(v) for k,v in self.__map.items()})
-
-    def enumerate(self):
-        for k,v in self.__map.items():
-            print(k, "::", type(v), str(v))
-
-    @abc.abstractmethod
-    def _populate(self):
-        pass
-
 class YamlContextualDataReference(ContextualDataReference):
 
     def __init__(self, path):
@@ -139,7 +70,7 @@ class YamlContextualDataReference(ContextualDataReference):
 
     def _populate(self):
         for context in self.__node:
-            self.add_record(context, dict(self.__node.get_section(context).items()))
+            self._add_record(context, dict(self.__node.get_section(context).items()))
 
 
 class __ExcelDataReference(ContextualDataReference):
@@ -173,7 +104,7 @@ class ExcelContextualDataReference(__ExcelDataReference):
                     cmap[context][name] = data_record[index+1]
         self.reader.close()
         for context, value in cmap.items():
-            self.add_record(context, value)
+            self._add_record(context, value)
 
 def R(query="", *, bucket=None, context=None, index=None):
     if context is not None and index is not None:
@@ -206,16 +137,21 @@ def R(query="", *, bucket=None, context=None, index=None):
     try:
         bucket, context_or_index, query = final_query.split('.', 2)
     except ValueError:
+        query = ""
         try:
             bucket, context_or_index = final_query.split('.', 1)
-            query = ""
         except:
-            raise Exception("Not able to form a valid reference query with provided data. Invalid query: {}".format(final_query))
+            context_or_index = ""
+            try:
+                bucket = final_query
+            except:
+                raise Exception("Not able to form a valid reference query with provided data. Invalid query: {}".format(final_query))
 
     try:
         context_or_index = int(context_or_index)
     except:
-        pass
+        if context_or_index == "":
+            context_or_index = None
 
     try:
         query = int(query)
@@ -224,10 +160,13 @@ def R(query="", *, bucket=None, context=None, index=None):
             query = None
 
     try:
-        if query is None:
-            return Arjuna.get_data_ref(bucket).record_for(context_or_index)
+        if context_or_index is not None:
+            if query is None:
+                return Arjuna.get_data_ref(bucket).record_for(context_or_index)
+            else:
+                return Arjuna.get_data_ref(bucket).record_for(context_or_index)[query]
         else:
-            return Arjuna.get_data_ref(bucket).record_for(context_or_index)[query]
+            return Arjuna.get_data_ref(bucket)
     except Exception as e:
         import traceback
         raise Exception("Error in retrieving reference value for: bucket: >>{}<<, context: >>{}<< and query >>{}<< in data reference. {}. {}".format(bucket, context, query, str(e), traceback.format_exc()))
