@@ -23,6 +23,8 @@ import io
 import time
 import datetime
 import threading
+import platform
+import multiprocessing
 # sys.stdout = io.TextIOWrapper(sys.stdout.buffer, encoding="UTF-8")
 # sys.stderr = io.TextIOWrapper(sys.stderr.buffer, encoding="UTF-8")
 
@@ -70,6 +72,49 @@ class ArjunaSingleton:
 
         from arjuna.tpi.engine.testwise import CurrentTestWiseContainer
         self.__current_test_wise_objects = CurrentTestWiseContainer()
+        self.__allowed_log_contexts = {"default"}
+        self.__bmproxy_server = None
+
+    def __start_bmproxy(self, config):
+        # BrowserMob
+        from browsermobproxy import Server
+        from arjuna.tpi.constant import ArjunaOption
+        capture_traffic = config.value(ArjunaOption.BROWSER_NETWORK_RECORDER_ENABLED)
+        if capture_traffic:
+            bmproxy_dir = config.value(ArjunaOption.TOOLS_BMPROXY_DIR)
+            sub_dirs = os.listdir(bmproxy_dir)
+            bmproxy_bin_dir = None
+            if "bin" in sub_dirs:
+                bmproxy_bin_dir = os.path.join(bmproxy_dir, "bin")
+            else:
+                sub_dirs.sort(reverse=True) # Last version will be picked.
+                for d in sub_dir:
+                    if d.startswith("browsermob"):
+                        bmproxy_bin_dir = os.path.join(bmproxy_dir, d, "bin")
+                        break
+
+            if bmproxy_bin_dir is None:
+                raise Exception("Network recording is enabled in configuration. There was an error in creating proxy server/server using BrowserMob Proxy. Could not find proxy package at {}".format(bmproxy_dir))
+            
+            if platform.system().lower() == "windows":
+                exe = "browsermob-proxy.bat"
+            else:
+                exe = "browsermob-proxy"
+            bmproxy_exe_path = os.path.join(bmproxy_bin_dir, exe)
+
+            try:
+                self.__bmproxy_server = Server(bmproxy_exe_path)
+                self.__bmproxy_server.start()
+            except ProxyServerError as e:
+                raise Exception("Network recording is enabled in configuration. There was an error in creating proxy server/server using BrowserMob Proxy. Fix and retry. Error message: {}".format(str(e)))
+
+    @property
+    def bmproxy_server(self):
+        return self.__bmproxy_server
+
+    @property
+    def allowed_log_contexts(self):
+        return self.__allowed_log_contexts
 
     @property
     def gui_mgr(self):
@@ -103,6 +148,8 @@ class ArjunaSingleton:
 
         from arjuna.engine.logger import Logger
         self.__logger = Logger(self.ref_config)
+        from arjuna import ArjunaOption
+        self.__allowed_log_contexts = self.ref_config.value(ArjunaOption.LOG_ALLOWED_CONTEXTS)
 
         from arjuna.tpi.hook.config import Configurator
         configurator = Configurator()
@@ -136,6 +183,8 @@ class ArjunaSingleton:
             if wyaml is not None:
                 self.__common_withx_ref = WithX(wyaml.as_map())
 
+        self.__start_bmproxy(self.ref_config)
+
         return self.ref_config
 
     @property
@@ -193,7 +242,11 @@ class ArjunaSingleton:
 
     def get_config(self, name):
         if name == "ref":
-            return self.ref_config
+            current_proc_name = multiprocessing.current_process().name
+            if current_proc_name == "MainProcess":
+                return self.ref_config
+            else:
+                return self.get_group_params()["config"]
         else:
             if not self.has_config(name):
                 raise UndefinedConfigError(name, tuple(self.__config_map.keys()))
@@ -206,18 +259,18 @@ class ArjunaSingleton:
         return name.lower() in self.__config_map
 
     def get_group_params(self):
-        return self.__thread_wise_group_params_map[threading.current_thread().name]
+        return self.__thread_wise_group_params_map[multiprocessing.current_process().name]
 
     def register_group_params(self, **params):
-        self.__thread_wise_group_params_map[threading.current_thread().name] = params
-        self.__thread_wise_ref_conf_map[threading.current_thread().name] = params['config']
+        self.__thread_wise_group_params_map[multiprocessing.current_process().name] = params
+        self.__thread_wise_ref_conf_map[multiprocessing.current_process().name] = params['config']
 
     def register_test_selector_for_group(self, selector):
-        self.__thread_wise_test_selector_map[threading.current_thread().name] = selector
+        self.__thread_wise_test_selector_map[multiprocessing.current_process().name] = selector
 
     def get_test_selector(self):
         try:
-            return self.__thread_wise_test_selector_map[threading.current_thread().name]
+            return self.__thread_wise_test_selector_map[multiprocessing.current_process().name]
         except KeyError:
             raise TestSelectorNotFoundError()
 
@@ -233,7 +286,7 @@ class ArjunaSingleton:
                 from arjuna import ArjunaOption
                 return self.__test_meta_data[self.get_config("ref").value(ArjunaOption.PROJECT_NAME) + "." + qual_name]
             except KeyError:
-                raise Exception("Test Meta data not found for test: {}. Existing entries: {}".format(qual_name, self.__test_meta_data.keys()))
+                raise Exception("Test Meta data not found for test: {}. If you have a function with prefix 'check_', verify if it is decorated with @test. Existing entries: {}".format(qual_name, self.__test_meta_data.keys()))
 
 class Arjuna:
     '''
@@ -262,6 +315,14 @@ class Arjuna:
         '''
         return cls.ARJUNA_SINGLETON.logger
 
+    @classmethod
+    def _get_allowed_log_contexts(cls):
+        return cls.ARJUNA_SINGLETON.allowed_log_contexts
+
+    @classmethod
+    def _get_bmproxy_server(cls):
+        return cls.ARJUNA_SINGLETON.bmproxy_server
+
     @classmethod
     def get_test_session(cls):
         '''
@@ -368,9 +429,11 @@ class Arjuna:
     def get_test_meta_data(cls, qual_name):
         return cls.ARJUNA_SINGLETON.get_test_meta_data(qual_name)
 
-    @staticmethod
-    def exit():
+    @classmethod
+    def exit(cls):
         '''
             Clean-up and finalise resources currently opened by Arjuna.
         '''
-        pass
\ No newline at end of file
+        proxy_server = cls._get_bmproxy_server()
+        if proxy_server is not None:
+            proxy_server.stop()
\ No newline at end of file
